@@ -1,21 +1,31 @@
 #ifndef __PYX_HAVE__lxml__etree
 #define __PYX_HAVE__lxml__etree
-#ifdef __cplusplus
-#define __PYX_EXTERN_C extern "C"
-#else
-#define __PYX_EXTERN_C extern
-#endif
 
+struct LxmlDocument;
+struct LxmlElement;
+struct LxmlElementTree;
+struct LxmlElementTagMatcher;
+struct LxmlElementIterator;
+struct LxmlElementBase;
+struct LxmlElementClassLookup;
+struct LxmlFallbackElementClassLookup;
+
+/* "src/lxml/lxml.etree.pyx":290
+ * cdef class _BaseParser
+ * cdef class QName
+ * ctypedef public xmlNode* (*_node_to_node_function)(xmlNode*)             # <<<<<<<<<<<<<<
+ * 
+ * ################################################################################
+ */
 typedef xmlNode *(*_node_to_node_function)(xmlNode *);
 
-/* "/home/sbehnel/source/Python/lxml/lxml-2.2/src/lxml/lxml.etree.pyx":234
+/* "src/lxml/lxml.etree.pyx":286
  * 
  * # forward declarations
  * cdef public class _Document [ type LxmlDocumentType, object LxmlDocument ]             # <<<<<<<<<<<<<<
  * cdef public class _Element [ type LxmlElementType, object LxmlElement ]
  * cdef class _BaseParser
  */
-
 struct LxmlDocument {
   PyObject_HEAD
   struct __pyx_vtabstruct_4lxml_5etree__Document *__pyx_vtab;
@@ -25,31 +35,28 @@ struct LxmlDocument {
   struct __pyx_obj_4lxml_5etree__BaseParser *_parser;
 };
 
-/* "/home/sbehnel/source/Python/lxml/lxml-2.2/src/lxml/lxml.etree.pyx":235
+/* "src/lxml/lxml.etree.pyx":287
  * # forward declarations
  * cdef public class _Document [ type LxmlDocumentType, object LxmlDocument ]
  * cdef public class _Element [ type LxmlElementType, object LxmlElement ]             # <<<<<<<<<<<<<<
  * cdef class _BaseParser
  * cdef class QName
  */
-
 struct LxmlElement {
   PyObject_HEAD
   PyObject *_gc_doc;
   struct LxmlDocument *_doc;
   xmlNode *_c_node;
   PyObject *_tag;
-  PyObject *_attrib;
 };
 
-/* "/home/sbehnel/source/Python/lxml/lxml-2.2/src/lxml/lxml.etree.pyx":1535
+/* "src/lxml/lxml.etree.pyx":1697
  * 
  * 
  * cdef public class _ElementTree [ type LxmlElementTreeType,             # <<<<<<<<<<<<<<
  *                                  object LxmlElementTree ]:
  *     cdef _Document _doc
  */
-
 struct LxmlElementTree {
   PyObject_HEAD
   struct __pyx_vtabstruct_4lxml_5etree__ElementTree *__pyx_vtab;
@@ -57,14 +64,13 @@ struct LxmlElementTree {
   struct LxmlElement *_context_node;
 };
 
-/* "/home/sbehnel/source/Python/lxml/lxml-2.2/src/lxml/lxml.etree.pyx":2097
+/* "src/lxml/lxml.etree.pyx":2314
  * 
  * 
  * cdef public class _ElementTagMatcher [ object LxmlElementTagMatcher,             # <<<<<<<<<<<<<<
  *                                        type LxmlElementTagMatcherType ]:
  *     cdef object _pystrings
  */
-
 struct LxmlElementTagMatcher {
   PyObject_HEAD
   struct __pyx_vtabstruct_4lxml_5etree__ElementTagMatcher *__pyx_vtab;
@@ -74,55 +80,58 @@ struct LxmlElementTagMatcher {
   char *_name;
 };
 
-/* "/home/sbehnel/source/Python/lxml/lxml-2.2/src/lxml/lxml.etree.pyx":2125
+/* "src/lxml/lxml.etree.pyx":2342
  *                 self._name = NULL
  * 
  * cdef public class _ElementIterator(_ElementTagMatcher) [             # <<<<<<<<<<<<<<
  *     object LxmlElementIterator, type LxmlElementIteratorType ]:
  *     # we keep Python references here to control GC
  */
-
 struct LxmlElementIterator {
   struct LxmlElementTagMatcher __pyx_base;
   struct LxmlElement *_node;
   _node_to_node_function _next_element;
 };
 
-/* "/home/sbehnel/source/Python/lxml/lxml-2.2/src/lxml/classlookup.pxi":6
+/* "/home/sbehnel/source/Python/lxml/lxml-release/src/lxml/classlookup.pxi":6
  * # Custom Element classes
  * 
  * cdef public class ElementBase(_Element) [ type LxmlElementBaseType,             # <<<<<<<<<<<<<<
  *                                           object LxmlElementBase ]:
  *     u"""ElementBase(*children, attrib=None, nsmap=None, **_extra)
  */
-
 struct LxmlElementBase {
   struct LxmlElement __pyx_base;
 };
 
+/* "/home/sbehnel/source/Python/lxml/lxml-release/src/lxml/classlookup.pxi":184
+ * # Element class lookup
+ * 
+ * ctypedef public object (*_element_class_lookup_function)(object, _Document, xmlNode*)             # <<<<<<<<<<<<<<
+ * 
+ * # class to store element class lookup functions
+ */
 typedef PyObject *(*_element_class_lookup_function)(PyObject *, struct LxmlDocument *, xmlNode *);
 
-/* "/home/sbehnel/source/Python/lxml/lxml-2.2/src/lxml/classlookup.pxi":148
+/* "/home/sbehnel/source/Python/lxml/lxml-release/src/lxml/classlookup.pxi":187
  * 
  * # class to store element class lookup functions
  * cdef public class ElementClassLookup [ type LxmlElementClassLookupType,             # <<<<<<<<<<<<<<
  *                                        object LxmlElementClassLookup ]:
  *     u"""ElementClassLookup(self)
  */
-
 struct LxmlElementClassLookup {
   PyObject_HEAD
   _element_class_lookup_function _lookup_function;
 };
 
-/* "/home/sbehnel/source/Python/lxml/lxml-2.2/src/lxml/classlookup.pxi":157
+/* "/home/sbehnel/source/Python/lxml/lxml-release/src/lxml/classlookup.pxi":196
  *         self._lookup_function = NULL # use default lookup
  * 
  * cdef public class FallbackElementClassLookup(ElementClassLookup) \             # <<<<<<<<<<<<<<
  *          [ type LxmlFallbackElementClassLookupType,
  *            object LxmlFallbackElementClassLookup ]:
  */
-
 struct LxmlFallbackElementClassLookup {
   struct LxmlElementClassLookup __pyx_base;
   struct __pyx_vtabstruct_4lxml_5etree_FallbackElementClassLookup *__pyx_vtab;
@@ -132,6 +141,23 @@ struct LxmlFallbackElementClassLookup {
 
 #ifndef __PYX_HAVE_API__lxml__etree
 
+#ifndef __PYX_EXTERN_C
+  #ifdef __cplusplus
+    #define __PYX_EXTERN_C extern "C"
+  #else
+    #define __PYX_EXTERN_C extern
+  #endif
+#endif
+
+__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlDocumentType;
+__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlElementType;
+__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlElementTreeType;
+__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlElementTagMatcherType;
+__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlElementIteratorType;
+__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlElementBaseType;
+__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlElementClassLookupType;
+__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlFallbackElementClassLookupType;
+
 __PYX_EXTERN_C DL_IMPORT(struct LxmlElement) *deepcopyNodeToDocument(struct LxmlDocument *, xmlNode *);
 __PYX_EXTERN_C DL_IMPORT(struct LxmlElementTree) *elementTreeFactory(struct LxmlElement *);
 __PYX_EXTERN_C DL_IMPORT(struct LxmlElementTree) *newElementTree(struct LxmlElement *, PyObject *);
@@ -169,23 +195,19 @@ __PYX_EXTERN_C DL_IMPORT(void) appendChild(struct LxmlElement *, struct LxmlElem
 __PYX_EXTERN_C DL_IMPORT(PyObject) *pyunicode(char *);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *utf8(PyObject *);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *getNsTag(PyObject *);
+__PYX_EXTERN_C DL_IMPORT(PyObject) *getNsTagWithEmptyNs(PyObject *);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *namespacedName(xmlNode *);
 __PYX_EXTERN_C DL_IMPORT(PyObject) *namespacedNameFromNsName(char *, char *);
 __PYX_EXTERN_C DL_IMPORT(void) iteratorStoreNext(struct LxmlElementIterator *, struct LxmlElement *);
 __PYX_EXTERN_C DL_IMPORT(void) initTagMatch(struct LxmlElementTagMatcher *, PyObject *);
 __PYX_EXTERN_C DL_IMPORT(xmlNs) *findOrBuildNodeNsPrefix(struct LxmlDocument *, xmlNode *, char *, char *);
 
-__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlDocumentType;
-__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlElementType;
-__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlElementTreeType;
-__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlElementTagMatcherType;
-__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlElementIteratorType;
-__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlElementBaseType;
-__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlElementClassLookupType;
-__PYX_EXTERN_C DL_IMPORT(PyTypeObject) LxmlFallbackElementClassLookupType;
-
-#endif
+#endif /* !__PYX_HAVE_API__lxml__etree */
 
+#if PY_MAJOR_VERSION < 3
 PyMODINIT_FUNC initetree(void);
-
+#else
+PyMODINIT_FUNC PyInit_etree(void);
 #endif
+
+#endif /* !__PYX_HAVE__lxml__etree */
