@@ -12,7 +12,7 @@ if this_dir not in sys.path:
     sys.path.insert(0, this_dir) # needed for Py3
 
 from common_imports import etree, StringIO, BytesIO, fileInTestDir, _bytes, _str
-from common_imports import SillyFileLike, HelperTestCase
+from common_imports import SillyFileLike, HelperTestCase, write_to_file
 
 try:
     unicode = __builtins__["unicode"]
@@ -40,12 +40,13 @@ class HtmlParserTestCase(HelperTestCase):
 
     def test_module_HTML(self):
         element = self.etree.HTML(self.html_str)
-        self.assertEqual(self.etree.tostring(element),
+        self.assertEqual(self.etree.tostring(element, method="html"),
                          self.html_str)
 
     def test_module_HTML_unicode(self):
         element = self.etree.HTML(self.uhtml_str)
-        self.assertEqual(unicode(self.etree.tostring(element, encoding='UTF8'), 'UTF8'),
+        self.assertEqual(unicode(self.etree.tostring(element, method="html",
+                                                     encoding='UTF8'), 'UTF8'),
                          unicode(self.uhtml_str.encode('UTF8'), 'UTF8'))
 
     def test_module_HTML_pretty_print(self):
@@ -194,7 +195,7 @@ class HtmlParserTestCase(HelperTestCase):
 
     def test_module_HTML_broken(self):
         element = self.etree.HTML(self.broken_html_str)
-        self.assertEqual(self.etree.tostring(element),
+        self.assertEqual(self.etree.tostring(element, method="html"),
                          self.html_str)
 
     def test_module_HTML_cdata(self):
@@ -210,12 +211,13 @@ class HtmlParserTestCase(HelperTestCase):
     def test_module_parse_html(self):
         parser = self.etree.HTMLParser()
         filename = tempfile.mktemp(suffix=".html")
-        open(filename, 'wb').write(self.html_str)
+        write_to_file(filename, self.html_str, 'wb')
         try:
             f = open(filename, 'rb')
             tree = self.etree.parse(f, parser)
             f.close()
-            self.assertEqual(self.etree.tostring(tree.getroot()), self.html_str)
+            self.assertEqual(self.etree.tostring(tree.getroot(), method="html"),
+                             self.html_str)
         finally:
             os.remove(filename)
 
@@ -223,7 +225,8 @@ class HtmlParserTestCase(HelperTestCase):
         parser = self.etree.HTMLParser()
         f = SillyFileLike(self.html_str)
         tree = self.etree.parse(f, parser)
-        html = self.etree.tostring(tree.getroot(), encoding='UTF-8')
+        html = self.etree.tostring(tree.getroot(),
+                                   method="html", encoding='UTF-8')
         self.assertEqual(html, self.html_str)
 
 ##     def test_module_parse_html_filelike_unicode(self):
@@ -247,7 +250,7 @@ class HtmlParserTestCase(HelperTestCase):
         self.etree.set_default_parser( self.etree.HTMLParser() )
 
         tree = self.etree.parse(BytesIO(self.broken_html_str))
-        self.assertEqual(self.etree.tostring(tree.getroot()),
+        self.assertEqual(self.etree.tostring(tree.getroot(), method="html"),
                          self.html_str)
 
         self.etree.set_default_parser()
@@ -285,6 +288,118 @@ class HtmlParserTestCase(HelperTestCase):
             [],
             [ event for (event, element) in events if event != 'end' ])
 
+    def test_html_iterparse_start(self):
+        iterparse = self.etree.iterparse
+        f = BytesIO(
+            '<html><head><title>TITLE</title><body><p>P</p></body></html>')
+
+        iterator = iterparse(f, html=True, events=('start',))
+        self.assertEquals(None, iterator.root)
+
+        events = list(iterator)
+        root = iterator.root
+        self.assert_(root is not None)
+        self.assertEquals(
+            [('start', root), ('start', root[0]), ('start', root[0][0]),
+                ('start', root[1]), ('start', root[1][0])],
+            events)
+
+    def test_html_parser_target_tag(self):
+        assertFalse  = self.assertFalse
+        events = []
+        class Target(object):
+            def start(self, tag, attrib):
+                events.append(("start", tag))
+                assertFalse(attrib)
+            def end(self, tag):
+                events.append(("end", tag))
+            def close(self):
+                return "DONE"
+
+        parser = self.etree.HTMLParser(target=Target())
+
+        parser.feed("<html><body></body></html>")
+        done = parser.close()
+
+        self.assertEquals("DONE", done)
+        self.assertEquals([
+            ("start", "html"), ("start", "body"),
+            ("end", "body"), ("end", "html")], events)
+
+    def test_html_parser_target_doctype_empty(self):
+        assertFalse  = self.assertFalse
+        events = []
+        class Target(object):
+            def start(self, tag, attrib):
+                events.append(("start", tag))
+                assertFalse(attrib)
+            def end(self, tag):
+                events.append(("end", tag))
+            def doctype(self, *args):
+                events.append(("doctype", args))
+            def close(self):
+                return "DONE"
+
+        parser = self.etree.HTMLParser(target=Target())
+        parser.feed("<!DOCTYPE><html><body></body></html>")
+        done = parser.close()
+
+        self.assertEquals("DONE", done)
+        self.assertEquals([
+            ("doctype", (None, None, None)),
+            ("start", "html"), ("start", "body"),
+            ("end", "body"), ("end", "html")], events)
+
+    def test_html_parser_target_doctype_html(self):
+        assertFalse  = self.assertFalse
+        events = []
+        class Target(object):
+            def start(self, tag, attrib):
+                events.append(("start", tag))
+                assertFalse(attrib)
+            def end(self, tag):
+                events.append(("end", tag))
+            def doctype(self, *args):
+                events.append(("doctype", args))
+            def close(self):
+                return "DONE"
+
+        parser = self.etree.HTMLParser(target=Target())
+        parser.feed("<!DOCTYPE html><html><body></body></html>")
+        done = parser.close()
+
+        self.assertEquals("DONE", done)
+        self.assertEquals([
+            ("doctype", ("html", None, None)),
+            ("start", "html"), ("start", "body"),
+            ("end", "body"), ("end", "html")], events)
+
+    def test_html_parser_target_doctype_html_full(self):
+        assertFalse  = self.assertFalse
+        events = []
+        class Target(object):
+            def start(self, tag, attrib):
+                events.append(("start", tag))
+                assertFalse(attrib)
+            def end(self, tag):
+                events.append(("end", tag))
+            def doctype(self, *args):
+                events.append(("doctype", args))
+            def close(self):
+                return "DONE"
+
+        parser = self.etree.HTMLParser(target=Target())
+        parser.feed('<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN" "sys.dtd">'
+                    '<html><body></body></html>')
+        done = parser.close()
+
+        self.assertEquals("DONE", done)
+        self.assertEquals([
+            ("doctype", ("html", "-//W3C//DTD HTML 4.01//EN", "sys.dtd")),
+            ("start", "html"), ("start", "body"),
+            ("end", "body"), ("end", "html")], events)
+
+
 def test_suite():
     suite = unittest.TestSuite()
     suite.addTests([unittest.makeSuite(HtmlParserTestCase)])
